@@ -6,21 +6,15 @@ library(FossilSim)
 t = ape::rtree(6)
 f = sim.fossils.poisson(rate = 2, tree = t)
 
-SAt = SAtree.from.fossils(t,f)
+SAt = SAtree.from.fossils(tree = t, fossils = f)
 print(SAt)
 print(SAt$complete)
 
 ## ------------------------------------------------------------------------
-plot(SAt)
+SAt_pruned = prune.fossils(tree = SAt)
+plot(SAt_pruned)
 
 ## ------------------------------------------------------------------------
-ape::plot.phylo(SAt)
-
-## ------------------------------------------------------------------------
-SAt_pruned = prune.fossils(SAt)
-ape::plot.phylo(SAt_pruned)
-
-## ------------------------------------------------------------------------
-SAt_sampled = sampled.tree.from.combined(SAt)
-ape::plot.phylo(SAt_sampled)
+SAt_sampled = sampled.tree.from.combined(tree = SAt)
+plot(SAt_sampled)
 
